texture MYTEXTURE0;
sampler MYSAMPLER0 =
	sampler_state
	{
		Texture = <MYTEXTURE0>;
		AddressU = WRAP;
		AddressV = Wrap;
		MipFilter = LINEAR;
		MinFilter = LINEAR;
		MagFilter = LINEAR;
	};

texture MYTEXTURE1;
sampler MYSAMPLER1 =
	sampler_state
	{
		Texture = <MYTEXTURE1>;
		AddressU = WRAP;
		AddressV = Wrap;
		MipFilter = LINEAR;
		MinFilter = LINEAR;
		MagFilter = LINEAR;
	};

texture MYTEXTURE2;
sampler MYSAMPLER2 =
	sampler_state
	{
		Texture = <MYTEXTURE2>;
		AddressU = WRAP;
		AddressV = Wrap;
		MipFilter = LINEAR;
		MinFilter = LINEAR;
		MagFilter = LINEAR;
	};


texture MYTEXTURE3;
sampler MYSAMPLER3 =
	sampler_state
	{
		Texture = <MYTEXTURE3>;
		AddressU = WRAP;
		AddressV = Wrap;
		MipFilter = LINEAR;
		MinFilter = LINEAR;
		MagFilter = LINEAR;
	};

struct VERTEX
{
	float3 m_Position : X3D_VSIN_POSITION; 
	float2 m_TexCoord0 : X3D_VSIN_TEXCOORD0;
};

struct INTERPOLANTS
{
    float4 m_Position   : POSITION;
    float2 m_TexCoord0  : TEXCOORD0;
    float2 m_TexCoord1  : TEXCOORD1;
    float2 m_TexCoord2  : TEXCOORD2;
    float2 m_TexCoord3  : TEXCOORD3;
};

float4x4 POSITION_TRANSFORM;
float4x4 UV_TRANSFORMS[4];

INTERPOLANTS 
	MyVertexShader
	(
		VERTEX vertex
	)
{
    INTERPOLANTS interpolants;
    
	interpolants.m_Position = mul(float4(vertex.m_Position, 1.f), POSITION_TRANSFORM);

	interpolants.m_TexCoord0 = mul(float4(vertex.m_TexCoord0, 0.f, 1.f), UV_TRANSFORMS[0]);
	interpolants.m_TexCoord1 = mul(float4(vertex.m_TexCoord0, 0.f, 1.f), UV_TRANSFORMS[1]);
	interpolants.m_TexCoord2 = mul(float4(vertex.m_TexCoord0, 0.f, 1.f), UV_TRANSFORMS[2]);
	interpolants.m_TexCoord3 = mul(float4(vertex.m_TexCoord0, 0.f, 1.f), UV_TRANSFORMS[3]);

    return interpolants;    
}

struct FRAGMENT
{
    float4 m_Color0 : COLOR0;
};

float4x4 COLOR_CORRECTION;

FRAGMENT 
	MyPixelShader
	(
		INTERPOLANTS interpolants
	) 
{ 
	float4 texel0 = tex2D(MYSAMPLER0, interpolants.m_TexCoord0);
	float4 texel1 = tex2D(MYSAMPLER1, interpolants.m_TexCoord1);
	float4 texel2 = tex2D(MYSAMPLER2, interpolants.m_TexCoord2);
	float4 texel3 = tex2D(MYSAMPLER3, interpolants.m_TexCoord3);
	
	texel0 = mul(texel0, COLOR_CORRECTION);
	texel1 = mul(texel1, COLOR_CORRECTION);
	texel2 = mul(texel2, COLOR_CORRECTION);
	texel3 = mul(texel3, COLOR_CORRECTION);

	float3 color0_rgb = texel0.xyz;
	color0_rgb = texel1.a * texel1.xyz + (1.f - texel1.a) * color0_rgb;
	color0_rgb = texel2.a * texel2.xyz + (1.f - texel2.a) * color0_rgb;
	color0_rgb = texel3.a * texel3.xyz + (1.f - texel3.a) * color0_rgb;

	color0_rgb = texel1.a * texel1.xyz + (1.f - texel1.a) * color0_rgb;
	color0_rgb = texel2.a * texel2.xyz + (1.f - texel2.a) * color0_rgb;
	color0_rgb = texel3.a * texel3.xyz + (1.f - texel3.a) * color0_rgb;

	color0_rgb = texel1.a * texel1.xyz + (1.f - texel1.a) * color0_rgb;
	color0_rgb = texel2.a * texel2.xyz + (1.f - texel2.a) * color0_rgb;
	color0_rgb = texel3.a * texel3.xyz + (1.f - texel3.a) * color0_rgb;

	FRAGMENT fragment;
    fragment.m_Color0.xyz = color0_rgb;
    fragment.m_Color0.a = 1.f;

    return fragment;
}

technique TECHNIQUE0
{
    pass PASS0
    {          
		CullMode = NONE;
		StencilEnable = FALSE;
		ZFunc = ALWAYS;
		ZWriteEnable = FALSE;
		AlphaBlendEnable = FALSE;
   
        VertexShader = compile vs_2_0 MyVertexShader();
        PixelShader  = compile ps_2_0 MyPixelShader();
    }
}
